package EFS::DBI::Result::Fileshare;

use strict;
use warnings;
use English;

use base q{EFS::DBI::Result};

use File::Basename qw(basename);

__PACKAGE__->load_components( qw/+EFS::DBI::Prefix Core/ );

__PACKAGE__->table( q{fileshare} );

__PACKAGE__->add_columns( qw( fileserver name filetype ) );
__PACKAGE__->add_columns(
    id => { __PACKAGE__->get_id_column_attrs },
);
__PACKAGE__->set_primary_key( q{id} );
__PACKAGE__->sequence( q{fileshare_seq} );

__PACKAGE__->belongs_to( fileserver => q{EFS::DBI::Result::Fileserver} );

__PACKAGE__->has_many( fileqtrees => q{EFS::DBI::Result::Fileqtree} );

__PACKAGE__->has_many( attrs => q{EFS::DBI::Result::FileshareAttrs} );

sub cell {
    return shift->fileserver->cell;
}

sub object_id {
    my $self = shift;
    my $separator = shift || q{:};
    return join( $separator,
                 $self->fileserver->name,
                 $self->name );
}

sub display_columns {
    return qw( cell fileserver name );
}

sub autoname {

    my $self = shift;

    my $autoname = q{};

    if ( $self->filetype eq q{dist} ) {
        $autoname = basename $self->name;
    } else {
        $autoname = join( q{_},
                          q{efs},
                          $self->filetype,
                          (split( m/\./msx, $self->cell->name ))[0,1] );
    }

    return $autoname;

}

1;

# Local Variables:
#   mode: cperl
#   cperl-indent-level: 4
#   fill-column: 78
# End:
# vim: expandtab shiftwidth=4:
