#!/usr/bin/env perl

use strict;
use warnings;
use English;

use lib q{test/lib};
use EFS::Test;
use Test::More tests => 9;
use File::Temp;
use User::pwent;
use User::grent;

# Don't use EFS::FQDN here
use Sys::Hostname::FQDN qw( fqdn );

my $test   = EFS::Test->new;
my $config = $test->get_config;
my $sshcmd = $config->get_value( q{Global}, q{sshcmd} );

ok(
    $config->get_value( q{LocalDevCell}, q{efsserver} ) eq fqdn,
    q{Localhost FQDN matches LocalDevCell efsserver},
);

my $rdc_efsserver = $config->get_value( q{RemoteDevCell}, q{efsserver} );
system(qq{$sshcmd $rdc_efsserver true});

ok(
    $CHILD_ERROR == 0,
    q{Password free ssh from LocalDevCell to RemoveDevCell enabled},
);

my $ldc_efsserver = $config->get_value( q{LocalDevCell}, q{efsserver} );
system(qq{$sshcmd $rdc_efsserver '$sshcmd $ldc_efsserver true'});

ok(
    $CHILD_ERROR == 0,
    q{Password free ssh from RemoveDevCell to LocalDevCell enabled},
);

my $pwd = $ENV{PWD};

my ($local_inode) = split( m{\s+}msx, qx{ ls -id $pwd } );

my ($remote_inode) = split( m{\s+}msx, qx{ $sshcmd $rdc_efsserver ls -id $pwd } );

ok(
    $local_inode && $remote_inode && $local_inode == $remote_inode,
    q{PWD is visible on RemoveDevCell efsserver},
);

my $primary_user = $config->get_value( q{Global}, q{primary_user} );
my $pw_dev = getpw( $primary_user );
ok(
    $pw_dev,
    qq{Primary user '$primary_user' specified in config, and exists},
);

my $secondary_user = $config->get_value( q{Global}, q{secondary_user} );
ok(
    $secondary_user,
    qq{Secondary user '$secondary_user' specified in config, and exists},
);

ok(
    $secondary_user ne $primary_user,
    qq{Primary user '$primary_user' and secondary user '$secondary_user' are not the same},
);

my $gr_dev = getgr( $pw_dev->gid );
my $primary_group_name = $gr_dev->name;

ok(
    grep( { $secondary_user } @{ $gr_dev->members } ),
    qq{Secondary user '$secondary_user' is in primary user's primary group, '$primary_group_name'},
);

# GSSAPI/Kerberos checks

SKIP: {

    if ( not $config->get_value( q{Security}, q{kerberos_realm} ) ) {
        skip q{Kerberos tests not configured}, 1;
    }

    # Check /etc/krb5.keytab exists, and has host and efsd services

    # Check /etc/krb5.conf has correct realm name

    ok( 1, q{Placeholder for Kerberos setup tests} );

}
