#!/usr/bin/env perl

use strict;
use warnings;
use English;

use Test::More tests => 20;

use lib q{test/lib};
use EFS::Test;

my $test = EFS::Test->new;
my $config = $test->get_config;

my $username  = $test->get_primary_username;
my $groupname = $test->get_primary_groupname;

$test->efs_test_command(
    name    => q{(setup) efs display metaproj testmeta},
    command => q{efs display metaproj testmeta},
    bail    => 1,
);

$test->efs_test_command(
    command => qq{efs undef userrights testmeta prod $username},
    expect  => qq{Removed $username prod rights to testmeta},
);

$test->efs_test_command(
    run_as  => q{efsops},
    command => qq{efs undef userrights testmeta admin $username},
    expect  => qq{Removed $username admin rights to testmeta},
);

$test->efs_test_command(
    run_as  => q{efsops},
    command => qq{efs define userrights nosuch admin $username},
    not     => 1,
    expect  => [
        q{No such metaproj 'nosuch'},
        q{Exit status from efs server not received.  Assuming failure...},
    ],
);

$test->efs_test_command(
    run_as  => q{efsops},
    command => qq{efs define userrights testmeta nosuch $username},
    not     => 1,
    expect  => [
        q{Invalid role 'nosuch'},
        q{Must be one of: dev, qa, prod, auto or admin},
    ],
);

$test->efs_test_command(
    run_as  => q{efsops},
    command => q{efs define userrights testmeta admin nosuchus},
    not     => 1,
    expect  => q{No such username 'nosuchus'},
);

$test->efs_test_command(
    run_as  => q{efsops},
    command => qq{efs define grouprights nosuch admin $groupname},
    not     => 1,
    expect  => [
        q{No such metaproj 'nosuch'},
        q{Exit status from efs server not received.  Assuming failure...},
    ],
);

$test->efs_test_command(
    run_as  => q{efsops},
    command => qq{efs define grouprights testmeta nosuch $groupname},
    not     => 1,
    expect  => [
        q{Invalid role 'nosuch'},
        q{Must be one of: dev, qa, prod, auto or admin},
    ],
);

$test->efs_test_command(
    run_as  => q{efsops},
    command => q{efs define grouprights testmeta admin nosuchgr},
    not     => 1,
    expect  => q{No such groupname 'nosuchgr'},
);

$test->efs_test_command(
    run_as  => q{efsops},
    command => qq{efs define userrights testmeta admin $username},
    expect  => qq{Granted $username admin rights to testmeta},
);

$test->efs_test_command(
    run_as  => q{efsops},
    command => qq{efs define userrights testmeta admin $username},
    expect  => qq{Username $username already has admin rights to testmeta},
);

$test->efs_test_command(
    run_as  => q{efsops},
    command => qq{efs undef userrights testmeta dev $username},
    not     => 1,
    expect  => [
        q{No such userrights object for metaproj 'testmeta',},
        qq{role 'dev', username '$username'},
    ],
);

$test->efs_test_command(
    run_as  => q{efsops},
    command => qq{efs undef userrights testmeta admin $username},
    expect  => qq{Removed $username admin rights to testmeta},
);

$test->efs_test_command(
    run_as  => q{efsops},
    command => qq{efs define grouprights testmeta admin $groupname},
    expect  => qq{Granted $groupname admin rights to testmeta},
);

$test->efs_test_command(
    run_as  => q{efsops},
    command => qq{efs define grouprights testmeta admin $groupname},
    expect  => qq{Groupname $groupname already has admin rights to testmeta},
);

$test->efs_test_command(
    run_as  => q{efsops},
    command => qq{efs undef grouprights testmeta dev $groupname},
    not     => 1,
    expect  => [
        q{No such grouprights object for metaproj 'testmeta',},
        qq{role 'dev', groupname '$groupname'},
    ],
);

$test->efs_test_command(
    run_as  => q{efsops},
    command => qq{efs undef grouprights testmeta admin $groupname},
    expect  => qq{Removed $groupname admin rights to testmeta},
);

$test->efs_test_command(
    command => qq{efs define userrights testmeta prod $username},
    not     => 1,
    expect  => [
        q{Access denied.},
        q{The 'admin' role is required to define userrights},
        q{Exit status from efs server not received.  Assuming failure...},
    ],
);

$test->efs_test_command(
    run_as  => q{efsops},
    command => qq{efs define userrights testmeta admin $username},
    expect  => qq{Granted $username admin rights to testmeta},
);

$test->efs_test_command(
    command => qq{efs define userrights testmeta prod $username},
    expect  => qq{Granted $username prod rights to testmeta},
);

