#!/usr/bin/env perl

use strict;
use warnings;
use English;

use Test::More qw( no_plan );

use lib q{test/lib};
use EFS::Test;

my $test = EFS::Test->new( as_user => q{efsops} );

my $region    = q{testregion};
my $campus    = q{testcampus};
my $location  = q{testlocation};
my $container = q{testcontainer};
my $hosttype  = q{test};

my $shortname = qq{$container.$hosttype};
my $longname  = qq{$region.$campus.$location.$container.$hosttype};

$test->efs_test_command(
    command => qq{efs define region $region 'test region'},
);

$test->efs_test_command(
    command => qq{efs define campus $region $campus 'test campus'},
);

$test->efs_test_command(
    command => qq{efs define location $region $campus $location 'test location'},
);

$test->efs_test_command(
    name    => q{Verifying that the pod doesn't exist...},
    command => qq{efs display pod -name $longname},
    not     => 1,
    bail    => 1,
    expect  => [ qq{No such pod '$longname'}, ],
);

$test->efs_test_command(
    command => qq{efs define pod $region $campus $location nodots desc},
    not     => 1,
    expect  => [
        q{Invalid pod name 'nodots'.},
        q{Must be 2 or 5 dot-separated fields.},
    ],
);

$test->efs_test_command(
    command => qq{efs define pod $region $campus $location r.c.l.$shortname desc},
    not     => 1,
    expect  => [
        qq{Invalid pod name 'r.c.l.$shortname'.},
        qq{The region.campus.location must match $region.$campus.$location},
    ],
);

$test->efs_test_command(
    command => qq{efs define pod $region $campus $location $region.$campus.$location.foo.bogushosttype desc},
    not     => 1,
    expect  => [
        qq{Invalid pod name '$region.$campus.$location.foo.bogushosttype'.},
        q{The hosttype must be one of: test, dev, qa, uat, prod},
    ],
);

$test->efs_test_command(
    command => qq{efs define pod $region $campus $location foo.bogushosttype desc},
    not     => 1,
    expect  => [
        q{Invalid pod name 'foo.bogushosttype'.},
        q{The hosttype must be one of: test, dev, qa, uat, prod},
    ],
);

$test->efs_test_command(
    command => qq{efs define pod $region $campus $location $longname temp},
    expect  => [ qq{Pod $longname defined}, ],
);

$test->efs_test_command(
    command => qq{efs define pod $region $campus $location $longname 'test pod'},
    expect  => [
        qq{Pod $longname already exists},
        qq{Updated description of pod $longname},
    ],
);

$test->efs_test_command(
    name    => q{Try to undef the location prematurely},
    command => qq{efs undef location $region $campus $location},
    not     => 1,
    expect  => [
        qq{Unable to undef location $region/$campus/$location, because it has},
        q{the following pods:},
        qq{$longname},
    ],
);

$test->efs_test_command(
    command => qq{efs setattr pod $region $campus $location $longname foo bar},
);

$test->efs_test_command(
    command => qq{efs display pod -name $shortname},
    not     => 1,
    expect  => [ q{Missing required arguments: region, campus, location}, ],
);

my @display = (
    qr{Location \s+ Pod \s+ Description}msx,
    qr{=+}msx,
    qr{$location \s+ $longname \s+ test \s+ pod}msx,
    qr{Pod \s+ Attribute \s+ Value}msx,
    qr{=+}msx,
    qr{$longname \s+ foo \s+ bar}msx,
);

$test->efs_test_command(
    command => qq{efs display pod $region $campus $location $shortname},
    expect  => \@display,
);

$test->efs_test_command(
    command => qq{efs display pod -name $longname},
    expect  => \@display,
);

$test->efs_test_command(
    command => qq{efs undef pod $region $campus $location $longname},
);

$test->efs_test_command(
    command => qq{efs undef location $region $campus $location},
);

$test->efs_test_command(
    command => qq{efs undef campus $region $campus},
);

$test->efs_test_command(
    command => qq{efs undef region $region},
);

$test->efs_test_command(
    command => qq{efs history pod -name $longname -count 3},
    expect  => [
        qr{History \s+ ID \s+ StartTime \s+ Duration \s+ Status \s+ Authuser \s+ Request}msx,
        qr{-+}msx,
        qr{define \s+ pod}msx,
        qr{setattr \s+ pod}msx,
        qr{undef \s+ pod}msx,
    ],
);

