#!/usr/bin/env perl

use strict;
use warnings;
use English;

use Test::More qw( no_plan );

use lib q{test/lib};
use EFS::Test;

my $test = EFS::Test->new( as_user => q{efsops} );

my $hostclass = q{testhostclass};

$test->efs_test_command(
    name    => q{Verifying that the hostclass doesn't exist...},
    command => qq{efs display hostclass $hostclass},
    expect  => [ qq{No such hostclass '$hostclass'}, ],
    bail    => 1,
    not     => 1,
);

$test->efs_test_command(
    name    => q{Define a bogus hostclass},
    command => q{efs define hostclass UPPERCASE desc},
    expect  => [
        q{Invalid hostclass 'UPPERCASE'},
        q{Must consist solely of lower case letters and numbers (a-z, 0-9),},
        q{dash (-), plus (+) and the underscore (_)},
        q{Exit status from efs server not received.  Assuming failure...},
    ],
    not => 1,
);

$test->efs_test_command(
    name    => qq{Define the hostclass $hostclass},
    command => qq{efs define hostclass $hostclass temp},
    expect  => [ qq{Defined hostclass '$hostclass'}, ],
);

$test->efs_test_command(
    name    => qq{Define the hostclass $hostclass, again},
    command => qq{efs define hostclass $hostclass 'test hostclass'},
    expect  => [
        qq{Hostclass '$hostclass' is already defined},
        qq{Updated description of hostclass $hostclass},
    ],
);

$test->efs_test_command(
    name    => q{Set an attribute for the hostclass},
    command => ( qq{efs setattr hostclass $hostclass foo bar}, ),
);

$test->efs_test_command(
    command => qq{efs display hostclass $hostclass},
    expect  => [
        qr{Hostclass \s+ Description}msx,
        qr{=+}msx,
        qr{$hostclass \s+ test \s+ hostclass}msx,
        qr{Hostclass \s+ Attribute \s+ Value}msx,
        qr{=+}msx,
        qr{$hostclass \s+ foo \s+ bar}msx,
    ],
);

$test->efs_test_command( command => qq{efs undef hostclass $hostclass}, );

$test->efs_test_command(
    command => qq{efs history hostclass $hostclass -count 3},
    expect  => [
        qr{History \s+ ID \s+ StartTime \s+ Duration \s+ Status \s+ Authuser \s+ Request}msx,
        qr{-+}msx,
        qr{define \s+ hostclass \s+ $hostclass}msx,
        qr{setattr \s+ hostclass \s+ $hostclass}msx,
        qr{undef \s+ hostclass \s+ $hostclass}msx,
    ],
);


