#!/usr/bin/env perl

use strict;
use warnings;
use English;

use Test::More qw( no_plan );

use lib q{test/lib};
use EFS::Test;

my $test = EFS::Test->new( as_user => q{efsops} );

my $name     = q{test-a.b-x.y};
my $platform = q{x86-64.rhel.5};
my $kernel   = q{vmlinux-a.b.c-x.y.z};
my $initrd   = q{initrd-a.b.c-x.y.z.img};
my $options  = q{a=b c=d e=f};
my $options2 = q{e=f c=d a=b};

$test->efs_test_command(
    command => qq{efs define platformbuild $name $platform $kernel $initrd "$options"},
    expect  => qq{Defined build $name},
);

$test->efs_test_command(
    command => qq{efs define platformbuild $name nosuch $kernel $initrd "$options"},
    not     => 1,
    expect  => q{No such platform 'nosuch'},
);

my @display = (
    qr{Platform \s+ Platformbuild \s+ Kernel \s+ Initrd \s+ Options}msx,
    qr{^=+}msx,
    qr{$platform \s+ $name \s+ $kernel \s+ $initrd}msx,
);

$test->efs_test_command(
    command => qq{efs display platformbuild $name},
    expect  => \@display,
);

$test->efs_test_command(
    command => qq{efs define platformbuild $name $platform $kernel $initrd "$options2"},
    expect => [
        qq{Verified platform value of '$platform'},
        qq{Verified kernel value of '$kernel'},
        qq{Verified initrd value of '$initrd'},
        qq{Updated options value to '$options2'},
    ],
);

$test->efs_test_command(
    command => qq{efs undef platformbuild $name},
    expect  => qq{Undefined build $name},
);

$test->efs_test_command(
    command => qq{efs history platformbuild $name -count 4},
    expect  => [
        qr{History \s+ ID \s+ StartTime \s+ Duration \s+ Status \s+ Authuser \s+ Request}msx,
        qr{-+}msx,
        qr{define \s+ platformbuild \s+ $name}msx,
        qr{define \s+ platformbuild \s+ $name}msx,
        qr{define \s+ platformbuild \s+ $name}msx,
        qr{undef \s+ platformbuild \s+ $name}msx,
    ],
);

