#!/usr/bin/env perl
use strict;
use warnings;
use English;

use blib;
use EFS;

use lib q{test/lib};
use EFS::Test;

use Test::More;

## no critic: RequireInterpolationOfMetachars

my $test   = EFS::Test->new( as_user => q{efsops} );
my $config = $test->get_config;

my $ldc_efsserver = $config->get_value( q{LocalDevCell},  q{efsserver} );
my $ldc_name      = $config->get_value( q{LocalDevCell},  q{name} );
my $rdc_name      = $config->get_value( q{RemoteDevCell}, q{name} );
my $lpc_name      = $config->get_value( q{LocalProdCell}, q{name} );
my $fstype        = $config->get_value( q{Filesystem},    q{type} );

my $sshcmd        = $config->get_value( q{Global}, q{sshcmd} );
my $rdc_efsserver = $config->get_value( q{RemoteDevCell}, q{efsserver} );

if ( $fstype ne q{afs} ) {
    plan skip_all => q{Cells are only uninitialized when testing AFS};
}

if ( not $config->get_value( q{Security}, q{kerberos_realm} ) ) {
    die qq{Unable to test AFS without a valid kerberos_realm\n};
}

foreach my $name ( $lpc_name, $ldc_name, $rdc_name ) {
    $test->efs_test_command( command => qq{efs hide cell $name} );
    $test->efs_test_command( command => qq{efs uninit cell $name} );
}

system( q{fs checkv > /dev/null} );
ok( $CHILD_ERROR == 0, q{fs checkvolumes on LocalDevCell} );

system( qq{$sshcmd $rdc_efsserver fs checkv > /dev/null} );
ok( $CHILD_ERROR == 0, q{fs checkvolumes on RemoveDevCell} );

done_testing();
exit 0;
